
* This Stata do file contains the Food and Grocery Expenditure panel
* regression models presented in G.F.Barrett and M.Brzozowski (2012)
* "Food Expenditure and Involuntary Retirement: Resolving the
* Retirement-Consumnption Puzzle," AJAE.

* The data source for the analysis is the Household, Income and Labour
* Dynamics in Australia (HILDA) Survey. The data can be accessed under
* license from MIAESR, see http://melbourneinstitute.com/hilda/
* The analysis in the article is based on HILDA Survey Release 7.0

* The following table provides the concordance between the variable
* names as used in this do file and the original HILDA datat variable
* labels
#delimit;

*Variable   Definition                          HILDA Survey Data Labels
--------------------------------------------------------------------------
 lnnety     ln weekly disposable income         ahifdip-ahifdin,
                                                to ghifdip-ghifdin
 xpgroc     ln weekly grocery expenditure       axpgroc-expgroc,
                                                fhxygroc-ghxygroc
 xpfood     ln weekly food expenditure          axpfood-expfood

 retire     retirement status indicator         ahges-ghges
 for        forced retirement indicator         crtfrpr, grtfrpr, retire
 ysincer    years since retired                 constructed from year,
                                                retire sequence
 forysr     for x ysincer                       constructed from  for,
                                                 year, retire sequence
 retchurn   indicator of 2+ transitions         retire sequence
             (=1 if re-enter workforce after retire)
 hgage      age of reference person             ahgage-ghgage
 dhhstate*  indicator for state of residence    ahhstate-ghhstate
 sepwiddiv  marital status indicator            ahgms,cmrcms-gmrcms
             (=1 if separated, widowed or divorced)
 spwk       indicator =1 if partner works       ahges-fhges for partner
 hhealth    indicator of health conditions      ahelth-ghelth
             (=1 if moderate or severe health conditions)
 hdisab     indicator of disability             ahglth-ghglth
 shealth   indicator for partner health         ahelthwk-ghelthwk (partner)
 sdisab    indicator for partner disability     ahglth-ghglth (partner)
 year      survey year                          wave identifier
 yr0607    indicator =1 if year=2006 or 2007    constructed from year
 xwaveid   individual identifier                xwaveid
 atrisk    indicator of at risk of retirement   ahgage, retire sequence
           (=1 if not retired in 2001 and age>=45)
 -------------------------------------------------------------------------
 NOTE HILDA convention is to use 1st letter of variable name to denote wave
  (a is wave 1-2001, g is wave 7-2007);

capture clear;
set more off;
set matsize 8500;
set mem 800m;

log using "c:\HILDA\ajae\results\ExpendRegs.log", t replace;
display "$S_DATE $S_TIME";
use "f:\HILDA\ajae\data\ExpPanel17";

xtset xwaveid year;
iis xwaveid;
tis year;

* Restrict the analysis to the "at risk" sample;
keep if atrisk==1;

*=========================================
 Disposable Income Panel Regressions
=========================================;

* Table 3 column (2)- FE, RE and Hausman test in sequence;

xtreg lnnety retire  hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab, fe;
estimates store fixed;
xtreg lnnety retire  hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab, re;
hausman fixed .;

* Table 3 column (3)- FE, RE and Hausman test in sequence;

xtreg lnnety retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab, fe;
estimates store fixed;
xtreg lnnety retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab, re;
hausman fixed .;

*===================================================
  Grocery Expenditure Panel Regressions
====================================================;

* Table 3 model (4)- FE, RE and Hausman test in sequence;

xtreg xpgroc retire yr0607 hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab, fe;
estimates store fixed;
xtreg xpgroc retire yr0607 hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab, re;
hausman fixed .;

* Table 3 model (5)- FE, RE and Hausman test in sequence;

xtreg xpgroc retire for yr0607 hgage dhhstate* sepwiddiv spwk 	hhealth
  hdisab shealth sdisab, fe;
estimates store fixed;
xtreg xpgroc retire for yr0607 hgage dhhstate* sepwiddiv spwk 	hhealth
  hdisab shealth sdisab, re;
hausman fixed .;

* Table 4 model (2)- FE, RE and Hausman test in sequence;

xtreg xpgroc retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab if year<2006, fe;
estimates store fixed;
xtreg xpgroc retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab if year<2006, re;
hausman fixed .;

* Table 4 model (3) - drop osbervations once make 2nd transitions;

xtreg xpgroc retire for yr0607 hgage dhhstate* sepwiddiv spwk 	hhealth
  hdisab shealth sdisab if retchurn==0, fe;
estimates store fixed;                                                                                      
xtreg xpgroc retire for yr0607 hgage dhhstate* sepwiddiv spwk 	hhealth
  hdisab shealth sdisab if retchurn==0, re;
hausman fixed .;

* Table 4 model (5)- omit all health and disability controls;

xtreg xpgroc retire for yr0607 hgage dhhstate*  sepwiddiv spwk, fe;
estimates store fixed;
xtreg xpgroc retire for yr0607 hgage dhhstate*  sepwiddiv spwk, re;
hausman fixed .;

* Table 4 model (7) - include control for years since retired - ysincer;

xtreg xpgroc retire for ysincer yr0607 hgage dhhstate* sepwiddiv spwk
  	hhealth hdisab shealth sdisab, fe;
estimates store fixed;
xtreg xpgroc retire for ysincer yr0607 hgage dhhstate* sepwiddiv spwk
  	hhealth hdisab shealth sdisab, re;
hausman fixed .;

* Appendix Table 2 model (2) - include control for years since retired
  and the interaction with forced;

xtreg xpgroc retire for ysincer forysr yr0607 hgage dhhstate* sepwiddiv
  spwk 	hhealth hdisab shealth sdisab, fe;
estimates store fixed;
xtreg xpgroc retire for ysincer forysr yr0607 hgage dhhstate* sepwiddiv
  spwk 	hhealth hdisab shealth sdisab, re;
hausman fixed .;

*===================================================
  Food Expenditure Panel Regressions
====================================================;

* Table 3 column (6) - do FE, RE and Hausman test;

xtreg xpfood retire hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab,fe;
estimates store fixed;
xtreg xpfood retire hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab,re;
hausman fixed .;

* Table 3 column (7) - do FE, RE and Hausman test;

xtreg xpfood retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab,fe;
estimates store fixed;
xtreg xpfood retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab,re;
hausman fixed .;


* Table 4 column (4) - drop osbervations who make further transitions
  after 1st spell of retirement;

xtreg xpfood retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab if retchurn==0,fe;
estimates store fixed;
xtreg xpfood retire for hgage dhhstate* sepwiddiv spwk hhealth hdisab
  shealth sdisab if retchurn==0,re;
hausman fixed .;

* Table 4 column (6) - omit all health and disability controls;

xtreg xpfood retire for hgage dhhstate* sepwiddiv spwk,fe;
estimates store fixed;
xtreg xpfood retire for hgage dhhstate* sepwiddiv spwk,re;
hausman fixed .;


* Table 4 model (8) - include control for years since retired - ysincer;

xtreg xpfood retire for ysincer hgage dhhstate* sepwiddiv spwk 	hhealth
  hdisab shealth sdisab,fe;
estimates store fixed;
xtreg xpfood retire for ysincer hgage dhhstate* sepwiddiv spwk 	hhealth
 hdisab shealth sdisab,re;
hausman fixed .;


* Appendix Table 2 model (3) - include control for years since retired
  and the interaction with forced;

xtreg xpfood retire for ysincer forysr hgage dhhstate* sepwiddiv spwk
  hhealth hdisab shealth sdisab,fe;
estimates store fixed;
xtreg xpfood retire for ysincer forysr hgage dhhstate* sepwiddiv spwk
  hhealth hdisab shealth sdisab,re;
hausman fixed .;

stop;
